from .rust_x3dh import *

class _X3DHSer:
    def __init__(self): pass

    def gen_3xdh_secrets_key_pairs(self): 
        u1_ints, u2_ints = generate_3xdh_secrets_key_pairs()
        return (bytes(u1_ints), bytes(u2_ints))
    
x3dh_ser = _X3DHSer()



import unittest
from rust_x3dh import x3dh_ser

class X3DHTest(unittest.TestCase):
    def test_shared_secret_keys(self):
        u1_shared_secret_key, u2_shared_secret_key = x3dh_ser.gen_3xdh_secrets_key_pairs()

        self.assertEqual(u1_shared_secret_key, u2_shared_secret_key)

if __name__ == '__main__':
    unittest.main()


from rust_x3dh import x3dh_ser

u1_shared_secret_key, u2_shared_secret_key = x3dh_ser.gen_3xdh_secrets_key_pairs()

print(f"[u1_shared_secret_key]:{u1_shared_secret_key}")
print(f"[u2_shared_secret_key]:{u2_shared_secret_key}")


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="rust_x3dh",
    version="0.1.1",
    author="Klaus Wong",
    author_email="wch.klaus@gmail.com",
    description="Embeded the xxxdh, which implementation of the Extended Triple Diffie-Hellman key exchange protocol written in Rust, on Python. xxxdh is written by Olexander Yermakov.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/hkk97/rust_x3dh",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Rust",
    ],
    python_requires=">=3.9",
)